import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Arrays;
import java.util.StringTokenizer;


/**
 * ICPC - CTU Open Contest 2019
 * Sample Solution: Coasters
 * 
 * @author Martin Kacer
 */
public class CoastersNumeric {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	boolean hasNextToken() {
		try {
			while (!st.hasMoreTokens()) {
				String line = input.readLine();
				if (line == null) return false;
				st = new StringTokenizer(line);
			}
		} catch (IOException ex) { throw new RuntimeException(ex); }
		return true;
	}
	String nextToken() {
		return (!hasNextToken()) ? null : st.nextToken();
	}
	int nextInt() {
		return Integer.parseInt(nextToken());
	}
	public static void main(String[] args) {
		new CoastersNumeric().run();
	}
	
	static final double EPS = 1E-8;
	double r, x1, x2, y1, y2;
	
	void run() {
		double x0 = nextInt(), y0 = nextInt();
		r = nextInt(); x1 = nextInt() - x0; y1 = nextInt() - y0; x2 = nextInt() - x0; y2 = nextInt() - y0;
		if (x1 > x2) { double t = x1; x1 = x2; x2 = t; }
		if (y1 > y2) { double t = y1; y1 = y2; y2 = t; }
		
		double[] ys = new double[10];
		ys[0] = Math.max(-r, y1); ys[1] = Math.min(r, y2);
		int yc = 2;
		if (0 > ys[0] && 0 < ys[1]) ys[yc++] = 0;
		if (Math.abs(x1) < r) {
			double y1c = Math.sqrt(r*r - x1*x1);
			if (y1c > ys[0] && y1c < ys[1]) ys[yc++] = y1c;
			if (-y1c > ys[0] && -y1c < ys[1]) ys[yc++] = -y1c;
		}
		if (Math.abs(x2) < r) {
			double y2c = Math.sqrt(r*r - x2*x2);
			if (y2c > ys[0] && y2c < ys[1]) ys[yc++] = y2c;
			if (-y2c > ys[0] && -y2c < ys[1]) ys[yc++] = -y2c;
		}
		double area = 0;
		if (ys[0] < ys[1]) {
			Arrays.sort(ys, 0, yc);
			for (int i = 1; i < yc; ++i) area += calcStripe(ys[i-1], ys[i]);
		}
		System.out.println(area);
	}
	
	double calcStripe(double yb, double yt) {
		double xbc = Math.sqrt(r*r - yb*yb), xtc = Math.sqrt(r*r - yt*yt);
		double xbl = Math.max(x1, -xbc), xbr = Math.min(x2, xbc),
				xtl = Math.max(x1, -xtc), xtr = Math.min(x2, xtc);
		if (xbl > xbr+EPS || xtl > xtr+EPS) return 0;
		double rect = (yt-yb) * (xbr+xtr-xbl-xtl) / 2;
		if (Math.abs(xbl-xtl) > EPS) rect += circSegment(xbl, yb, xtl, yt);
		if (Math.abs(xbr-xtr) > EPS) rect += circSegment(xbr, yb, xtr, yt);
		//System.err.println("  - "+yb+"-"+yt+" x " + xbl+'/'+xtl+'-'+xbr+'/'+xtr + " -> " + rect);
		return rect;
	}
	
	double circSegment(double xa, double ya, double xb, double yb) {
		double s = Math.hypot(xb - xa, yb - ya);
		double alpha = 2 * Math.asin(s / 2 / r);
		return r*r / 2 * (alpha - Math.sin(alpha));
	}
}
