#include <bits/stdc++.h>
using namespace std;
typedef long long int ll;
typedef double ld;

#define EPS (1e-10)
#define EQ(a,b) (fabs(a-b) <= fabs(a+b) * EPS)
#define DEB(...) cerr<<#__VA_ARGS__<<": "<<__VA_ARGS__<<endl

struct Pt{
    ld x,y;
    bool operator <(const Pt &p) const {
        return x < p.x || x == p.x && y < p.y;
    }
    Pt operator-(){return{-x,-y};}
    Pt operator+(const Pt&p){return{x+p.x,y+p.y};}
    Pt operator-(const Pt&p){return{x-p.x,y-p.y};}
    Pt operator*(ld d){return {x*d,y*d};}
    Pt operator/(ld d){return {x/d,y/d};}
    friend ostream &operator<<(ostream &os, const Pt&a){
        os<<a.x<<' '<<a.y;
        return os;
    }
    friend istream &operator>>(istream &is, Pt&a){
        is>>a.x>>a.y;
        return is;
    }
};
struct Line {
    Pt a,b;
    Line(Pt a,Pt b):a(a),b(b){}
    bool operator<(Line &l){
        Pt v=b-a,w=l.b-l.a;
        return atan2(v.y, v.x) < atan2(w.y, w.x);
    }
};
struct Cir {
    Pt s;
    ld r;
    Pt point(double a)const{return {s.x+cos(a)*r,s.y+sin(a)*r};}  
    bool operator<(const Cir& a){return r<a.r;}  
};

ld vec(Pt a, Pt b){ return a.x*b.y-a.y*b.x; }
ld vec(Pt a, Pt b, Pt c){ return vec(b-a,c-a); }
ld dot(Pt a, Pt b){ return a.x*b.x+a.y*b.y; }
ld norm(Pt a){ return sqrt(dot(a,a)); }
ld points_distance(Pt a, Pt b){ return norm(b-a); }
Pt scaleTo(Pt a, ld res){return a*(res/norm(a));}
ld angle(Pt a,Pt b){return acos(dot(a,b)/norm(a)/norm(b));}
ld line_point_dist(Line l, Pt p){
    return abs(vec(p-l.a,l.b-l.a)/norm(l.b-l.a));
}

ld cld(Cir a, Line b){
    return max(line_point_dist(b,a.s)-a.r,0.);
}
Pt lines_intersection(Line p,Line q){
    Pt v=p.b-p.a;
    Pt w=q.b-q.a;
    ld t=vec(w,p.a-q.a)/vec(v,w);
    return p.a+v*t;
}
Pt normal(Pt a){ ld n=norm(a); return {-a.y/n,a.x/n}; }
Pt lpdp(Line &a, Pt &b){
    return lines_intersection(a,{b,b+normal(a.b-a.a)});
}
ll clpp(Cir a, Line b, Pt &p1, Pt &p2){
    if(cld(a,b)>0)return 0;
    Pt dv=lpdp(b,a.s);
    ld d=norm(dv);
    ld h=sqrt(a.r*a.r-d*d);
    Pt n=scaleTo(b.b-b.a,h);

    p1=dv+n;
    p2=dv-n;
    //cout<<"clpp\n";
    //cout<<a.s<<' '<<b.a<<' '<<b.b<<endl;
    //cout<<dv<<endl;
    //cout<<d<<endl;
    //cout<<h<<endl;
    //cout<<n<<endl;
    //cout<<p1<<endl;
    //cout<<p2<<endl;
    //cout<<"---\n";
    return 1+!(EQ(p1.x,p2.x) && EQ(p1.y,p2.y));
}

ld getCircleIntersectionArea(Line l, Cir c){
    Pt ra=scaleTo(l.a,c.r);
    Pt rb=scaleTo(l.b,c.r);
    Pt center=(l.a+l.b)/2;
    if(norm(l.a)>norm(ra)){l.a=ra;}
    if(norm(l.b)>norm(rb)){l.b=rb;}
    ld v=vec(ra,rb);
    ld sign=v>0?1:-1;
    //cout<<"test"<<center<<' '<<norm(center)<<' '<<c.r<<endl;
    if(norm(center)>c.r-2*EPS){
        ld arc_area=abs(angle(ra,rb)*c.r*c.r/2);
        //DEB("arc "<<arc_area<<' '<<angle(ra,rb)/M_PI*180);
        return sign*arc_area;
    }else{
        ld triangle_area=abs(vec(l.a,l.b))/2;
        //DEB("tri "<<triangle_area);
        return sign*triangle_area;
    }
}

ld circleRectangleIntersection(vector<Pt> rect, Cir c){
    ld res=0;
    // split segments so that no segment crosses with the circle circumference
    vector<Pt> poly;
    for(int i=0; i<rect.size(); ++i){
        Line l(rect[i], rect[(i+1)%rect.size()]);
        Pt a, b;
        ll intersections=clpp(c, l, a, b);
        Line orig=l;
        if(l.a.x>l.b.x)swap(l.a.x,l.b.x);
        if(l.a.y>l.b.y)swap(l.a.y,l.b.y);
        poly.push_back(orig.a);
        //DEB(intersections);
        if(intersections==2){
            if(points_distance(orig.a, a)>points_distance(orig.a, b)){
                swap(a,b);
            }
            if(l.a.x-EPS<a.x&&a.x-EPS<l.b.x && l.a.y-EPS<a.y&&a.y-EPS<l.b.y){
                //DEB("adding "<<a);
                poly.push_back(a);
            }
            if(l.a.x-EPS<b.x&&b.x-EPS<l.b.x && l.a.y-EPS<b.y&&b.y-EPS<l.b.y){
                //DEB("adding "<<b);
                poly.push_back(b);
            }
        }
    }
    //DEB("result polygon");
    //for(Pt a:poly)DEB(a);
    for(int i=0; i<poly.size(); ++i){
        ld q=getCircleIntersectionArea(Line(poly[i], poly[(i+1)%poly.size()]), c);
        //DEB("res: "<<q);
        res+=q;
    }
    return abs(res);
}

int main(){
    Cir c;cin>>c.s>>c.r;
    Pt a,b;cin>>a>>b;
    if(a.x>b.x)swap(a.x,b.x);
    if(a.y>b.y)swap(a.y,b.y);
    // normalize coordinates so that the center of the circle is on (0,0)
    a=a-c.s;
    b=b-c.s;
    c.s={EPS,EPS};
    // construct the full rectangle
    vector<Pt> rect;
    Pt d={a.x,b.y};
    Pt e={b.x,a.y};
    rect.push_back(a);
    rect.push_back(d);
    rect.push_back(b);
    rect.push_back(e);
    cout<<fixed<<setprecision(12);
    //DEB("test");
    //for(Pt a:rect)DEB(a);
    cout<<circleRectangleIntersection(rect, c)<<endl;
    return 0;
}

