/**
 * CTU Open 2019
 * Problem Solution: Intersection
 * Idea: Start with the circle, subtract half-plane intersection areas and then
 * add qudrant intersection areas (because they were subtracted twice).
 */

import java.util.*;
import java.io.*;
import java.math.*;
import java.text.DecimalFormat;

public class prunik {
  static final DecimalFormat OUTFORM = new DecimalFormat("0.0000");
  public class Circle {
    public Circle(double x_, double y_, double r_) {
      x=x_; y=y_; r=r_;
    }

    // area to the right of vertical line at linex
    // this function assumes x=y=0
    double areaHalfPlane(double linex) {
      if(linex >= r)
        return 0;
      if(linex < 0)
        return Math.PI*r*r - areaHalfPlane(-linex);
      if(linex == 0)
        return Math.PI*r*r/2.0;
      // half of the length of the circular segment
      double hlen = Math.sqrt(r*r - linex*linex); 
      double triangleArea = hlen*linex;
      // half of the angle of the circular sector
      double hangle = Math.asin(hlen/r);
      return hangle*r*r - triangleArea;
    }

    // area to the right qx and above qy
    // this function assumes x=y=0
    double areaQuadrant(double qx, double qy) {
      if(qx < 0 && qy < 0)
        return Math.PI*r*r - areaHalfPlane(-qx) - areaHalfPlane(-qy) + areaQuadrant(-qx, -qy);
      if(qx < 0)
        return areaHalfPlane(qy) - areaQuadrant(-qx, qy);
      if(qy < 0)
        return areaHalfPlane(qx) - areaQuadrant(qx, -qy);
      if(qx*qx + qy*qy >= r*r)
        return 0;
      // y-coordinate of the intersection with the quadrant's vertical half-line
      double qxy = Math.sqrt(r*r - qx*qx);
      // x-coordinate of the intersection with the quadrant's horizontal half-line
      double qyx = Math.sqrt(r*r - qy*qy);
      // length of the circular segment
      double len = Math.sqrt((qxy-qy)*(qxy-qy) + (qyx-qx)*(qyx-qx));
      // half of the angle of the circular sector
      double hangle = Math.asin(len/(2.0*r));
      // area of the triangle in the intersection with the quadrant
      double triangleArea = (qxy-qy)*(qyx-qx)/2.0;
      // distance from the center to the circular segment
      double dst = Math.sqrt(r*r - len*len/4.0);
      double segmentArea = hangle*r*r - dst*len/2.0;
      return triangleArea + segmentArea;
    }

    double x,y,r;
  }

  public class Rectangle {
    public Rectangle(double x1_, double y1_, double x2_, double y2_) {
      x1=Math.min(x1_,x2_); y1=Math.min(y1_,y2_); x2=Math.max(x1_,x2_); y2=Math.max(y1_,y2_);
    }
    void shift(double sx, double sy) {
      x1 += sx;
      x2 += sx;
      y1 += sy;
      y2 += sy;
    }
    double x1,y1,x2,y2;
  }

  StringTokenizer st = new StringTokenizer("");
  BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
  String nextToken() throws IOException {
    while (!st.hasMoreTokens()) st = new StringTokenizer(input.readLine());
    return st.nextToken();
  }
  double nextDouble() throws IOException {
    return Double.parseDouble(nextToken());
  }
  Circle readCircle() throws IOException {
    double cx = nextDouble(), cy = nextDouble(), r = nextDouble();
    return new Circle(cx,cy,r);
  }
  Rectangle readRectangle() throws IOException {
    double x1 = nextDouble(), y1 = nextDouble(), x2 = nextDouble(), y2 = nextDouble();
    return new Rectangle(x1, y1, x2, y2);
  }

  private void run() throws IOException {
    Circle c = readCircle();
    Rectangle r = readRectangle();
    r.shift(-c.x, -c.y);
    c.x = c.y = 0;
    double result = Math.PI*c.r*c.r;
    result -= c.areaHalfPlane(-r.x1);
    result -= c.areaHalfPlane(r.x2);
    result -= c.areaHalfPlane(-r.y1);
    result -= c.areaHalfPlane(r.y2);
    result += c.areaQuadrant(-r.x1,-r.y1);
    result += c.areaQuadrant(-r.x1,r.y2);
    result += c.areaQuadrant(r.x2,r.y2);
    result += c.areaQuadrant(r.x2,-r.y1);
    System.out.println(OUTFORM.format(result));
  }

  public static void main( String[] args ) throws IOException {
    new prunik().run();
  }
}
